@@ -39,7 +39,7 @@ namespace {
 		if(num > std::numeric_limits<N>::max())
 			return fmt::format("{}: {} position {} must fit in {} bits", argv0, name, position, sizeof(N) * 8);
 		if(*end != '\0')
-			return fmt::format("{}: {} position {}: {}", argv0, name, position, errno ? strerror(errno) : "not a number");
+			return fmt::format("{}: {} position {}: {}", argv0, name, position, errno ? std::strerror(errno) : "not a number");
 
 		return T{static_cast<N>(num)};
 	}
